npbrain.synapses package
========================

.. currentmodule:: npbrain.synapses
.. automodule:: npbrain.synapses


.. autosummary::
    :toctree: _autosummary

    AMPA1
    AMPA2
    GABAa1
    GABAa2
    GABAb1
    GABAb2
    GapJunction
    GapJunction_LIF
    NMDA
    VoltageJumpSynapse
    STP

